@@ -1,22 +1,15 @@
-// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2014-2021 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #ifndef TAO_PEGTL_HPP
 #define TAO_PEGTL_HPP
 
 #include "pegtl/config.hpp"
-#include "pegtl/version.hpp"
-
 #include "pegtl/parse.hpp"
+#include "pegtl/version.hpp"
 
 #include "pegtl/ascii.hpp"
 #include "pegtl/rules.hpp"
-#include "pegtl/uint16.hpp"
-#include "pegtl/uint32.hpp"
-#include "pegtl/uint64.hpp"
-#include "pegtl/uint8.hpp"
-#include "pegtl/utf16.hpp"
-#include "pegtl/utf32.hpp"
 #include "pegtl/utf8.hpp"
 
 #include "pegtl/argv_input.hpp"
@@ -27,7 +20,7 @@
 #include "pegtl/read_input.hpp"
 #include "pegtl/string_input.hpp"
 
-// this has to be included *after* the above inputs,
+// This has to be included *after* the above inputs,
 // otherwise the amalgamated header will not work!
 #include "pegtl/file_input.hpp"
 
@@ -45,9 +38,10 @@
 #include "pegtl/discard_input_on_failure.hpp"
 #include "pegtl/discard_input_on_success.hpp"
 
-// The following are not included by
-// default because they include <iostream>.
+#include "pegtl/visit.hpp"
 
-// #include "pegtl/analyze.hpp"
+#if defined( __cpp_exceptions )
+#include "pegtl/must_if.hpp"
+#endif
 
 #endif
